==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/Effect/filewriter/translations/filewriter_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>EffectFileWriterFactory</name>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="30"/>
        <source>File Writer Plugin</source>
        <translation>Engadido File Writer</translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="51"/>
        <source>About File Writer Plugin</source>
        <translation>Acerca do engadido File Writer</translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="52"/>
        <source>Qmmp File Writer Plugin</source>
        <translation>Engadido Qmmp File Writer</translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Writer Plugin Settings</source>
        <translation>Opcións do engadido File Writer</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Output directory:</source>
        <translation>Directorio de saída:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="59"/>
        <source>Output file name:</source>
        <translation>Nome de ficheiro de saída:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Quality:</source>
        <translation>Calidade:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="69"/>
        <source>Choose a directory</source>
        <translation>Escoller un directorio</translation>
    </message>
</context>
</TS>

==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/Effect/filewriter/translations/filewriter_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>EffectFileWriterFactory</name>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="30"/>
        <source>File Writer Plugin</source>
        <translation>Engadido File Writer</translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="51"/>
        <source>About File Writer Plugin</source>
        <translation>Acerca do engadido File Writer</translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="52"/>
        <source>Qmmp File Writer Plugin</source>
        <translation>Engadido Qmmp File Writer</translation>
    </message>
    <message>
        <location filename="../effectfilewriterfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Writer Plugin Settings</source>
        <translation>Opcións do engadido File Writer</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Output directory:</source>
        <translation>Directorio de saída:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Output file name:</source>
        <translation>Nome de ficheiro de saída:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="109"/>
        <source>Write to single file if possible.</source>
        <translation>Escribir a un arquivo único se é posible.</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="36"/>
        <source>Quality:</source>
        <translation>Calidade:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="71"/>
        <source>Choose a directory</source>
        <translation>Escoller un directorio</translation>
    </message>
</context>
</TS>
